@@ -1,7 +1,9 @@
 """Contains back-ends for qutrunk."""
 from .backend import Backend
 from .local import BackendLocal
-from .qusprout import BackendQuSprout, ExecType
+from .qusprout import BackendQuSprout
 # performance issue, import by qutrunk.backends.braket.BackendAWSLocal/BackendAWSDevice
 # from .braket import BackendAWSLocal, BackendAWSDevice
+from .qusaas import BackendQuSaas
 from .ibm import BackendIBM
+from .result import MeasureQubit, MeasureQubits, MeasureCount, MeasureResult
