@@ -8,17 +8,17 @@ from .ryy import Ryy
 from .rz import Rz, CRz
 from .rzz import Rzz
 from .swap import Swap, SwapGate, CSwap, CSwapGate
-from .x import X, NOT, XGate, CX, CNOT, Toffoli, MCX
-from .y import Y, YGate, CY, CYGate
-from .z import Z, ZGate, CZ, MCZ
+from .x import X, NOT, XGate, CX, CNOT, Toffoli, MCX, PauliX
+from .y import Y, YGate, CY, CYGate, PauliY
+from .z import Z, ZGate, CZ, MCZ, PauliZ
 from .u1 import U1, CU1
 from .u3 import U3, CU3, CU
 from .u3 import U3 as U
 from .barrier import Barrier, BarrierGate
-from .basicgate import BasicGate, Observable, PauliType
-from .meta import All, Power, Inv, gate
+from .basicgate import BasicGate, Observable, PauliType, PauliCoeff, PauliCoeffs
+from .meta import All, Power, Gate, Matrix
 from .cr import CR
-from .iswap import iSwap
+from .iswap import iSwap, iSwapGate
 from .measure import Measure, MeasureGate
 from .s import S, SGate
 from .sdg import Sdg, SdgGate
@@ -30,7 +30,7 @@ from .u2 import U2
 from .x1 import X1, X1Gate
 from .y1 import Y1, Y1Gate
 from .z1 import Z1, Z1Gate
-from .i import I, IGate
+from .i import I, IGate, PauliI
 from .sxdg import SqrtXdg, SqrtXdgGate
 
 CTRL_CNT_PARAM = "ctrl_cnt"
