@@ -5,33 +5,23 @@ from qutrunk.circuit import Command
 from qutrunk.circuit.qubit import QuBit
 
 
-class iSwap(BasicGate):
-    """Performs a iSWAP gate between qubit1 and qubit2.
-
-    Args:
-        alpha: Rotation angle.
+class iSwapGate(BasicGate):
+    """Performs a iSwap gate between qubit1 and qubit2.
 
     Example:
         .. code-block:: python
 
-            iSwap(pi/2) * (qr[0], qr[1])
+            iSwap * (qr[0], qr[1])
     """
 
-    def __init__(self, alpha):
-        """
-        Args:
-            alpha: Rotation angle
-        """
-        if alpha is None:
-            raise NotImplementedError("The argument cannot be empty.")
+    def __init__(self):
         super().__init__()
-        self.rotation = alpha
 
     def __str__(self):
         return "iSwap"
 
     def __or__(self, qubits):
-        """Quantum logic gate operation
+        """Quantum logic gate operation.
 
         Args:
             qubit: The quantum bit to aplly iSwap gate.
@@ -39,21 +29,21 @@ class iSwap(BasicGate):
         Example:
             .. code-block:: python
 
-                iSwap(pi/2) * (qr[0], qr[1])
+                iSwap * (qr[0], qr[1])
 
         Raises:
             NotImplementedError: If the argument is not a Qubit object.
             AttributeError: If the qubits should not be two.
         """
         if not all(isinstance(qubit, QuBit) for qubit in qubits):
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         if len(qubits) != 2:
-            raise AttributeError("Parameter Error: Two target bits are required.")
+            raise ValueError("Parameter Error: Two target bits are required.")
 
         self.qubits = qubits
         targets = [q.index for q in qubits]
-        cmd = Command(self, targets, inverse=self.is_inverse, rotation=[self.rotation])
+        cmd = Command(self, targets, inverse=self.is_inverse)
         self.commit(qubits[0].circuit, cmd)
 
     def __mul__(self, qubits):
@@ -63,9 +53,13 @@ class iSwap(BasicGate):
     @property
     def matrix(self):
         """Access to the matrix property of this gate."""
-        half_alpha = float(self.rotation)
-        cos = np.cos(half_alpha)
-        sin = np.sin(half_alpha)
-        return np.matrix(
-            [[1, 0, 0, 0], [0, cos, -1j * sin, 0], [0, -1j * sin, cos, 0], [0, 0, 0, 1]]
-        )
+        return np.matrix([[1, 0, 0, 0], [0, 0, 1j, 0], [0, 1j, 0, 0], [0, 0, 0, 1]])
+
+    def inv(self):
+        """Apply inverse gate."""
+        gate = iSwapGate()
+        gate.is_inverse = not self.is_inverse
+        return gate
+
+
+iSwap = iSwapGate()
