@@ -32,10 +32,10 @@ class SqrtXdgGate(BasicGate):
                 SqrtXdg * qr[0]
 
         Raises:
-            NotImplementedError: If the argument is not a Qubit object.
+            TypeError: If the argument is not a Qubit object.
         """
         if not isinstance(qubit, QuBit):
-            raise NotImplementedError("The argument must be Qubit object.")
+            raise TypeError("The argument must be Qubit object.")
 
         targets = [qubit.index]
         cmd = Command(self, targets, inverse=self.is_inverse)
@@ -49,7 +49,13 @@ class SqrtXdgGate(BasicGate):
     @property
     def matrix(self):
         """Access to the matrix property of this gate."""
-        return np.matrix([[1 - 1j, 1 + 1j], [1 + 1j, 1 - 1j]]) / 2
+        return 0.5 * np.array([[1 - 1j, 1 + 1j], [1 + 1j, 1 - 1j]])
+
+    def inv(self):
+        """Apply inverse gate."""
+        gate = SqrtXdgGate()
+        gate.is_inverse = not self.is_inverse
+        return gate
 
 
 SqrtXdg = SqrtXdgGate()
