@@ -53,7 +53,7 @@ class TGate(BasicGate):
     @property
     def matrix(self):
         """Access to the matrix property of this gate."""
-        return np.array([[1, 0], [0, cmath.exp(1j * cmath.pi / 4)]])
+        return np.array([[1, 0], [0, (1 + 1j) / np.sqrt(2)]])
 
     def inv(self):
         """Apply inverse gate(TdgGate)."""
