@@ -32,7 +32,7 @@ from qutrunk.circuit.gates import (
     R,
     Ryy,
     SqrtSwapGate,
-    iSwap,
+    iSwapGate,
     CR,
     X1Gate,
     Y1Gate,
@@ -88,7 +88,7 @@ qutrunk_standard_gate = {
     "r": R,
     "ryy": Ryy,
     "sqrtswap": SqrtSwapGate,
-    "iswap": iSwap,
+    "iswap": iSwapGate,
     "cr": CR,
     "x1": X1Gate,
     "y1": Y1Gate,
