@@ -44,14 +44,15 @@ def run_grover(qubits=10, backend=None):
     res = circuit.run()
 
     # Get measure result and print as int
-    out = res.get_outcome()
-    print("measure result: " + str(int(out, base=2)))
+    outlist = res.get_bitstrs()
+    for out in outlist:
+        print("measure result: " + str(int(out, base=2)))
 
     # Print quantum circuit resource information
     circuit.show_resource()
 
     # Print quantum circuit execution information
-    print(res.excute_info())
+    print(res.running_info())
 
     return circuit
 
