@@ -7,10 +7,6 @@ from qutrunk.circuit.gates import NOT, Barrier, P, All, Measure
 from qutrunk.circuit.ops import QPE
 
 
-def _bin_int(itrable):
-    return int("".join(map(str, reversed(itrable))), base=2)
-
-
 def run_qpe(backend=None):
     """Estimate T-gate phase."""
     # allocate
@@ -28,18 +24,12 @@ def run_qpe(backend=None):
     # measure q1
     All(Measure) * q1
 
-    # print circuit
-    # qc.print()
-
     # run circuit
-    qc.run(shots=100)
-
-    # print result
-    print(q1.to_cl())
+    result = qc.run()
 
     # calculate the value of theta
-    f = _bin_int(q1.to_cl())
-    theta = f / 2 ** len(q1)
+    vals = result.get_values(q1)
+    theta = vals[0] / 2 ** len(q1)
     print("θ=", theta)
 
     return qc
