@@ -9,7 +9,7 @@ from qutrunk.circuit.gates import H, CNOT, Measure
 
 def run_check_sprout(ip: Optional[str] = None, port: Optional[int] = None):
     # allocate
-    qc = QCircuit(backend=BackendQuSprout(ip, port))
+    qc = QCircuit(backend=BackendQuSprout(ip=ip, port=port))
     qr = qc.allocate(2)
 
     # apply gate
@@ -26,7 +26,7 @@ def run_check_sprout(ip: Optional[str] = None, port: Optional[int] = None):
     print("==========circuit running result=========")
     print(res.get_counts())
     print("===========circuit running info==========")
-    print(res.excute_info())
+    print(res.running_info())
     print(
         f"qutrunk {qutrunk.__version__} is installed successfully! You can use QuTrunk now."
     )
